summaryrefslogtreecommitdiff
path: root/indra/newview/llvoavatarself.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llvoavatarself.cpp')
-rwxr-xr-xindra/newview/llvoavatarself.cpp7
1 files changed, 4 insertions, 3 deletions
diff --git a/indra/newview/llvoavatarself.cpp b/indra/newview/llvoavatarself.cpp
index 3605383c5c..9be1de4f0e 100755
--- a/indra/newview/llvoavatarself.cpp
+++ b/indra/newview/llvoavatarself.cpp
@@ -2264,7 +2264,7 @@ public:
else
{
LL_WARNS("Avatar") << "Failed " << status << " reason " << reason << LL_ENDL;
- error(status,reason);
+ errorWithContent(status,reason,content);
}
}
@@ -2440,11 +2440,12 @@ public:
}
// Error
/*virtual*/ void error(U32 status, const std::string& reason)
{
if (isAgentAvatarValid())
{
- LL_DEBUGS("Avatar") << "failed, will rebake" << llendl;
+ LL_DEBUGS("Avatar") << "failed, will rebake [status:"
+ << status << "]: " << content << llendl;
forceAppearanceUpdate();
}
}
@@ -2440,11 +2440,12 @@ public:
}
// Error
- /*virtual*/ void error(U32 status, const std::string& reason)
+ /*virtual*/ void errorWithContent(U32 status, const std::string& reason, const LLSD& content)
{
if (isAgentAvatarValid())